GalSampler
==========
Tools for generating synthetic cosmological data.


Installation
============
The latest release of galsampler, v0.1.0, can be installed with conda-forge::

      $ conda install lsstdesc-galsampler

To install galsampler into your environment from the source code::

      $ cd /path/to/root/galsampler
      $ pip install .

However you install the code, to use it from a python interpreter::

      >>> import galsampler


Documentation
=============
See https://galsampler.readthedocs.io/en/latest for complete documentation and usage tutorials.

Citation information
====================
The galsampler paper has been published in MNRAS. Citation information for the paper can be found at [this ADS link](https://ui.adsabs.harvard.edu/abs/2020MNRAS.495.5040H/exportcitation), copied below for convenience::

      @ARTICLE{2020MNRAS.495.5040H,
            author = {{Hearin}, Andrew and {Korytov}, Danila and {Kovacs}, Eve and {Benson}, Andrew and {Aung}, Han and {Bradshaw}, Christopher and {Campbell}, Duncan and {LSST Dark Energy Science Collaboration}},
            title = "{Generating synthetic cosmological data with GalSampler}",
            journal = {\mnras},
      keywords = {large-scale structure of Universe, Astrophysics - Cosmology and Nongalactic Astrophysics},
            year = 2020,
            month = jul,
            volume = {495},
            number = {4},
            pages = {5040-5051},
            doi = {10.1093/mnras/staa1495},
      archivePrefix = {arXiv},
            eprint = {1909.07340},
      primaryClass = {astro-ph.CO},
            adsurl = {https://ui.adsabs.harvard.edu/abs/2020MNRAS.495.5040H},
            adsnote = {Provided by the SAO/NASA Astrophysics Data System}
      }

